@@ -15,8 +15,8 @@
 
 import logging
 import os
+from six.moves.urllib.parse import urlparse
 import sys
-import urlparse
 
 from dataflake.docbuilder.utils import shell_cmd
 
@@ -25,20 +25,13 @@ class RCSClient(object):
     """ RCS client base class.
     """
 
-    def __init__( self
-                , trunk_name='trunk'
-                , tags_name='tags'
-                , logger=logging.getLogger()
-                ):
+    def __init__(self, trunk_name='trunk', tags_name='tags',
+                 logger=logging.getLogger()):
         self.trunk_name = trunk_name
         self.tags_name = tags_name
         self.logger = logger
 
-    def checkout_or_update( self
-                          , url
-                          , workingdir
-                          , trunk_only=True
-                          ):
+    def checkout_or_update(self, url, workingdir, trunk_only=True):
         package_info = {}
         package_name = self.name_from_url(url)
         package_dir = os.path.join(workingdir, package_name)
@@ -77,23 +70,24 @@ class RCSClient(object):
                 self.checkout_tag(package_url, tag, tag_path)
                 self.activate_egg(tag_path)
             else:
-                 msg = 'Already checked out: %s %s' % (package_name, tag)
-                 self.logger.info(msg)
+                msg = 'Already checked out: %s %s' % (package_name, tag)
+                self.logger.info(msg)
 
         return tag_names
 
     def activate_egg(self, egg_path):
         """ Create the EGG_INFO structure in a checkout
         """
-        pythonpath = ':'.join(sys.path)
-        cmd = 'PYTHONPATH="%s" %s %s/setup.py egg_info' % (
-                pythonpath, sys.executable, egg_path)
-        shell_cmd(cmd, fromwhere=egg_path)
+        if 'setup.py' in os.listdir(egg_path):
+            pythonpath = ':'.join(sys.path)
+            cmd = 'PYTHONPATH="%s" %s %s/setup.py egg_info' % (
+                    pythonpath, sys.executable, egg_path)
+            shell_cmd(cmd, fromwhere=egg_path)
 
     def name_from_url(self, url):
         """ Determine a package name from its VCS URL
         """
-        parsed_url = urlparse.urlparse(url)
+        parsed_url = urlparse(url)
         return [x for x in parsed_url[2].split('/') if x][-1]
 
     def checkout(self, url, targetpath):
@@ -114,8 +108,8 @@ class HGClient(RCSClient):
     def update(self, checkout_path):
         """ Update an existing checkout
         """
-        shell_cmd('hg pull -u', fromwhere=checkout_path)       
-    
+        shell_cmd('hg pull -u', fromwhere=checkout_path)
+
     def checkout(self, url, checkout_path):
         """ Check out from a repository
         """
@@ -136,16 +130,16 @@ class HGClient(RCSClient):
             tag, revision = line.split()
             if tag != 'tip':
                 tags.append(tag)
-        tags.sort()
-        return tags
+        return sorted(tags)
+
 
 class GitClient(RCSClient):
 
     def update(self, checkout_path):
         """ Update an existing checkout
         """
-        shell_cmd('git pull -a', fromwhere=checkout_path)       
-    
+        shell_cmd('git pull -a', fromwhere=checkout_path)
+
     def checkout(self, url, checkout_path):
         """ Check out from a repository
         """
@@ -166,8 +160,7 @@ class GitClient(RCSClient):
         if output:
             for line in output.split('\n'):
                 tags.append(line.strip())
-            tags.sort()
-        return tags
+        return sorted(tags)
 
 
 class SVNClient(RCSClient):
@@ -193,6 +186,4 @@ class SVNClient(RCSClient):
         """
         cmd = 'svn ls %s/%s' % (url, self.tags_name)
         tag_names = [x.replace('/', '') for x in shell_cmd(cmd).split()]
-        tag_names.sort()
-        return tag_names
-
+        return sorted(tag_names)
